@@ -70,7 +70,7 @@ class BunkrCrawler:
         """Removes the additional string bunkr adds to the end of every filename"""
         filename = filename.rsplit(ext, 1)[0]
         filename = filename.rsplit("-", 1)[0]
-        if not ext in filename:
+        if ext not in filename:
             filename = filename + ext
         return filename
 
