@@ -178,6 +178,8 @@ class XenforoCrawler:
     async def get_links(self, post_content, selector, attribute, domain, temp_title):
         """Grabs links from the post content based on the given selector and attribute"""
         found_links = []
+        if not post_content:
+            return found_links
         links = post_content.select(selector)
         for link in links:
             link = link.get(attribute)
@@ -219,6 +221,7 @@ class XenforoCrawler:
         returns external links, adds internal to the cascade"""
         forum_direct_urls = [x for x in content_links if x[0].host.replace(".st", ".su") in url.host]
         forum_direct_urls.extend([x for x in content_links if url.host in x[0].host.replace(".st", ".su")])
+        forum_direct_urls.extend([x for x in content_links if "smgmedia" in x[0].host])
         content_links = [x for x in content_links if x not in forum_direct_urls]
         for link_title_bundle in forum_direct_urls:
             link = link_title_bundle[0]
@@ -297,7 +300,7 @@ class XenforoCrawler:
 
             # Get Attachments
             attachments_block = post.select_one("section[class=message-attachments]")
-            content_links.extend(await self.get_links(post_content, "a[class='file-preview js-lbImage']", "href", domain, temp_title))
+            content_links.extend(await self.get_links(attachments_block, "a[class='file-preview js-lbImage']", "href", domain, temp_title))
 
         # Handle links
         content_links = await self.filter_content_links(cascade, content_links, url, "simpcity")
@@ -372,7 +375,7 @@ class XenforoCrawler:
 
             # Get Attachments
             attachments_block = post.select_one("section[class=message-attachments]")
-            content_links.extend(await self.get_links(post_content, "a[class='file-preview js-lbImage']", "href", domain, temp_title))
+            content_links.extend(await self.get_links(attachments_block, "a[class='file-preview js-lbImage']", "href", domain, temp_title))
 
         # Handle links
         content_links = await self.filter_content_links(cascade, content_links, url, "socialmediagirls")
@@ -447,7 +450,7 @@ class XenforoCrawler:
 
             # Get Attachments
             attachments_block = post.select_one("section[class=message-attachments]")
-            content_links.extend(await self.get_links(post_content, "a[class='file-preview js-lbImage']", "href", domain, temp_title))
+            content_links.extend(await self.get_links(attachments_block, "a[class='file-preview js-lbImage']", "href", domain, temp_title))
 
         # Handle links
         content_links = await self.filter_content_links(cascade, content_links, url, "xbunker")
